==> django-sysinfo-1.1.tar.gz: django-sysinfo-1.1/src/django_sysinfo/views.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, unicode_literals

import codecs
import logging
from functools import wraps

from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.core.exceptions import PermissionDenied
from django.http import HttpResponse, JsonResponse

from .api import UNKNOWN, get_sysinfo, get_version, run_check

HTTP_HEADER_ENCODING = "iso-8859-1"

logger = logging.getLogger(__name__)


def is_authorized(user):
    if user.is_superuser:
        return True
    return user.username in getattr(settings, "SYSINFO_USERS", [])


def http_basic_auth(func):
    @wraps(func)
    def _decorator(request, *args, **kwargs):
        from django.contrib.auth import authenticate, login

        if "HTTP_AUTHORIZATION" in request.META:
            authmeth, auth = request.META["HTTP_AUTHORIZATION"].split(b" ", 1)
            if authmeth.lower() == b"basic":
                auth = codecs.decode(auth.strip(), "base64")
                username, password = auth.split(b":", 1)
                user = authenticate(username=username, password=password)
                if user and is_authorized(user):
                    login(request, user)
                else:
                    raise PermissionDenied()
        return func(request, *args, **kwargs)

    return _decorator


def http_basic_login(func):
    return http_basic_auth(login_required(func))


# class Encoder(DjangoJSONEncoder):
#     def default(self, obj):
#         if callable(obj):
#             return obj.__name__
#         return json.JSONEncoder.default(self, obj)


def sysinfo(request):
    try:
        return JsonResponse(get_sysinfo(request))
    except Exception as e:  # pragma: no cover
        logger.exception(e)
        return JsonResponse({"Error": str(e)}, status=400)


def version(request, name):
    version = get_version(name)
    if version == UNKNOWN:
        status = 404
    else:
        status = 200
    data = {name: version}
    return JsonResponse(data, status=status)


def echo(request, value):
    return HttpResponse(value)


def check(request, id):
    try:
        ret, status = run_check(id)
        return JsonResponse({"message": ret}, status=status)
    except Exception as e:  # pragma: no cover
        return JsonResponse({"error": str(e)}, status=500)

==> django-sysinfo-1.3.0.tar.gz: django-sysinfo-1.3.0/src/django_sysinfo/views.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, unicode_literals

import codecs
import logging
from functools import wraps

from django.conf import settings
from django.contrib.auth.decorators import login_required, user_passes_test
from django.core.cache import cache
from django.core.exceptions import PermissionDenied
from django.http import HttpResponse, JsonResponse
from django.shortcuts import render
from django.utils.cache import patch_cache_control
from django.views.decorators.cache import never_cache

from django_sysinfo.conf import config

from .api import UNKNOWN, get_sysinfo, get_version, run_check

HTTP_HEADER_ENCODING = "iso-8859-1"

logger = logging.getLogger(__name__)


def is_authorized(user):
    if user.is_superuser:
        return True
    return user.username in getattr(settings, "SYSINFO_USERS", [])


def http_basic_auth(func):
    @wraps(func)
    def _decorator(request, *args, **kwargs):
        from django.contrib.auth import authenticate, login
        if "HTTP_AUTHORIZATION" in request.META:
            authmeth, auth = request.META["HTTP_AUTHORIZATION"].split(" ", 1)
            if authmeth.lower() == "basic":
                auth = codecs.decode(auth.encode("utf8").strip(), "base64").decode()
                username, password = auth.split(":", 1)
                user = authenticate(username=username, password=password)
                if user and is_authorized(user):
                    login(request, user)
                else:
                    raise PermissionDenied()
        return func(request, *args, **kwargs)

    return _decorator


def http_basic_login(func):
    return http_basic_auth(login_required(func))


def sysinfo(request):
    KEY = 'sysinfo/info2'
    try:
        content = cache.get(KEY)

        if not content:
            content = get_sysinfo(request)

        if config.ttl > 0:
            cache.set(KEY, dict(content), config.ttl)

        response = JsonResponse(content, safe=False)
        patch_cache_control(response, max_age=config.ttl, public=False)

        return response
    except Exception as e:  # pragma: no cover
        logger.exception(e)
        return JsonResponse({"Error": str(e)}, status=400)


def version(request, name):
    version = get_version(name)
    if version == UNKNOWN:
        status = 404
    else:
        status = 200
    data = {name: version}
    return JsonResponse(data, status=status)


@never_cache
def echo(request, value):
    return HttpResponse(value)


def check(request, id):
    try:
        ret, status = run_check(id)
        return JsonResponse({"message": ret}, status=status)
    except Exception as e:  # pragma: no cover
        return JsonResponse({"error": str(e)}, status=500)


@user_passes_test(is_authorized)
def admin_sysinfo(request):
    context = {'title': 'sysinfo',
               'infos': get_sysinfo(request)
               }
    return render(request, 'admin/sysinfo/sysinfo.html', context)
